# Change overview
# 1.0.6
* **calview** improvement: show in progress timebox as well, assuming end-time to be "now"

# 1.0.4
* **calview** improvement: show weekend (Saturday and Sunday) in matrix view, if time has been logged on weekends. 
  Otherwise default to 5 day, Monday to Friday week. Contributed by [nedimAT](https://github.com/nedimAT).

# 1.0.3
* as of this version, the end time of an entry must be **after** the start time of said entry 